@@ -7,7 +7,16 @@
 
 """JS/CSS Webpack bundles for TU Wien theme."""
 
+from flask_webpackext import WebpackBundleProject
 from invenio_assets.webpack import WebpackThemeBundle
+from pywebpack import bundles_from_entry_point
+
+project = WebpackBundleProject(
+    __name__,
+    project_folder="assets",
+    config_path="build/config.json",
+    bundles=bundles_from_entry_point("invenio_assets.webpack"),
+)
 
 theme = WebpackThemeBundle(
     __name__,
